@@ -13,15 +13,17 @@ use tree_sitter::Parser;
 
 use self::config::Config;
 use super::Backend;
+use crate::config::CMAKE_LINT_CONFIG;
 use crate::consts::TREESITTER_CMAKE_LANGUAGE;
 use crate::fileapi::DEFAULT_QUERY;
 use crate::formatting::getformat;
 use crate::gammar::{checkerror, ErrorInformation, LintConfigInfo};
 use crate::semantic_token::LEGEND_TYPE;
+use crate::utils::treehelper::ToPosition;
 use crate::utils::{did_vcpkg_project, treehelper, DocumentNormalize, VCPKG_LIBS, VCPKG_PREFIX};
 use crate::{
-    ast, complete, document_link, fileapi, filewatcher, hover, jump, scansubs, semantic_token,
-    utils, BackendInitInfo,
+    ast, complete, document_link, fileapi, filewatcher, hover, jump, quick_fix, scansubs,
+    semantic_token, utils, BackendInitInfo,
 };
 
 pub static BUFFERS_CACHE: LazyLock<Arc<Mutex<HashMap<lsp_types::Url, String>>>> =
@@ -61,7 +63,7 @@ impl Backend {
             .expect("Should have been inited before")
     }
 
-    async fn path_in_project<P: AsRef<Path>>(&self, path: P) -> bool {
+    fn path_in_project<P: AsRef<Path>>(&self, path: P) -> bool {
         let Some(root_path) = self.root_path() else {
             return true;
         };
@@ -86,7 +88,7 @@ impl Backend {
             return;
         };
 
-        if !self.path_in_project(&file_path).await {
+        if !self.path_in_project(&file_path) {
             return;
         }
 
@@ -100,10 +102,8 @@ impl Backend {
                 severity,
             } in diagnoses.inner
             {
-                let pointx =
-                    lsp_types::Position::new(start_point.row as u32, start_point.column as u32);
-                let pointy =
-                    lsp_types::Position::new(end_point.row as u32, end_point.column as u32);
+                let pointx = start_point.to_position();
+                let pointy = end_point.to_position();
                 let range = Range {
                     start: pointx,
                     end: pointy,
@@ -236,6 +236,7 @@ impl LanguageServer for Backend {
                 version: Some(version),
             }),
             capabilities: ServerCapabilities {
+                code_action_provider: Some(CodeActionProviderCapability::Simple(true)),
                 text_document_sync: Some(TextDocumentSyncCapability::Options(
                     TextDocumentSyncOptions {
                         open_close: Some(true),
@@ -341,8 +342,7 @@ impl LanguageServer for Backend {
         self.client
             .log_message(MessageType::INFO, "initialized!")
             .await;
-        let root_path_lock = self.root_path();
-        let root_path = root_path_lock;
+
         let work_done_token = ProgressToken::Number(1);
         let progress = self
             .client
@@ -352,7 +352,7 @@ impl LanguageServer for Backend {
             .begin()
             .await;
 
-        if let Some(ref project_root) = root_path {
+        if let Some(ref project_root) = self.root_path() {
             progress
                 .report_with_message(&format!("start scanning {}", project_root.display()), 10)
                 .await;
@@ -514,6 +514,27 @@ impl LanguageServer for Backend {
             .await;
     }
 
+    async fn code_action(&self, params: CodeActionParams) -> Result<Option<CodeActionResponse>> {
+        let Some(toolong) = params
+            .context
+            .diagnostics
+            .iter()
+            .find(|dia| dia.message.starts_with("[C0301]"))
+        else {
+            return Ok(None);
+        };
+
+        let uri = params.text_document.uri;
+        let storemap = BUFFERS_CACHE.lock().await;
+
+        let Some(context) = storemap.get(&uri) else {
+            return Ok(None);
+        };
+
+        let line = params.range.start.line;
+        Ok(quick_fix::lint_fix_action(context, line, toolong, uri))
+    }
+
     async fn did_change(&self, input: DidChangeTextDocumentParams) {
         // create a parse
         let uri = input.text_document.uri.clone();
@@ -533,7 +554,10 @@ impl LanguageServer for Backend {
             .await;
         }
         self.client
-            .log_message(MessageType::INFO, &format!("{input:?}"))
+            .log_message(
+                MessageType::INFO,
+                &format!("update file: {}", input.text_document.uri),
+            )
             .await;
     }
 
@@ -566,7 +590,7 @@ impl LanguageServer for Backend {
             context.to_string(),
             LintConfigInfo {
                 use_lint: self.init_info().enable_lint,
-                use_extra_cmake_lint: true,
+                use_extra_cmake_lint: CMAKE_LINT_CONFIG.enable_external_cmake_lint,
             },
         )
         .await;
@@ -664,6 +688,7 @@ impl LanguageServer for Backend {
             None => Ok(None),
         }
     }
+
     async fn references(&self, input: ReferenceParams) -> Result<Option<Vec<Location>>> {
         let uri = input.text_document_position.text_document.uri;
         let location = input.text_document_position.position;
@@ -672,8 +697,6 @@ impl LanguageServer for Backend {
             return Ok(None);
         };
         drop(storemap);
-        let mut parse = Parser::new();
-        parse.set_language(&TREESITTER_CMAKE_LANGUAGE).unwrap();
         let file_path = match uri.to_file_path() {
             Ok(file_path) => file_path,
             Err(_) => {
@@ -683,6 +706,7 @@ impl LanguageServer for Backend {
         };
         Ok(jump::godef(location, context.as_str(), &file_path, &self.client, false).await)
     }
+
     async fn goto_definition(
         &self,
         input: GotoDefinitionParams,
@@ -739,6 +763,7 @@ impl LanguageServer for Backend {
             None => Ok(None),
         }
     }
+
     async fn semantic_tokens_full(
         &self,
         params: SemanticTokensParams,
